@@ -267,7 +267,7 @@ class BaseScheduler(metaclass=_RequireAttrsABCMeta):
         return str(self._extra_script) or ""
 
     def write_job_script(self, name: str) -> None:
-        with open(self.batch_fname(name), "w") as f:
+        with open(self.batch_fname(name), "w", encoding="utf-8") as f:
             job_script = self.job_script()
             f.write(job_script)
 
@@ -385,9 +385,9 @@ class PBS(BaseScheduler):
         # files directly instead of at the end of the job. The downside
         # is that the logfiles are put in the homefolder.
         home = os.path.expanduser("~/")
-        stdout, stderr = [
+        stdout, stderr = (
             os.path.join(home, f"{name}.{x}{self._JOB_ID_VARIABLE}") for x in "oe"
-        ]
+        )
         return [stdout, stderr]
 
     def job_script(self) -> str:
